==> custom-toolbox_24.6.tar.xz: BUILD/translations/custom-toolbox_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Custom Toolbox</source>
        <translation>Niestandardowy zestaw narzędzi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Dostosuj program uruchamiający</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Zamknij program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>To jest niestandardowy program uruchamiający</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Pokaż to okno podczas uruchamiania</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>szukaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Open List File</source>
        <translation>Otwórz plik listy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>List Files (*.list)</source>
        <translation>Pliki list (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>File Selection Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>No file selected. Application will now exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>File Open Error</source>
        <translation>Błąd otwierania pliku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The file %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Could not open file: </source>
        <translation>Nie można otworzyć&#xa0;pliku:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Custom Toolbox to narzędzie służące do tworzenia niestandardowego programu uruchamiającego</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 License</source>
        <translation>%1 Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>%1 Help</source>
        <translation>%1 Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Could not write file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>File Removal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Could not remove file: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Tej aplikacji można używać do tworzenia niestandardowych programów uruchamiających: okna z przyciskami / ikonami</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Nie pokazuj pola wyboru „pokaż to okno dialogowe podczas uruchamiania”.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Pełna ścieżka i nazwa pliku .list, który chcesz załadować, aby skonfigurować aplikację</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Wygląda na to, że jesteś zalogowany jako root, wyloguj się i zaloguj jako zwykły użytkownik, aby korzystać z tego programu.</translation>
    </message>
</context>
</TS>

==> custom-toolbox_25.2.tar.xz: BUILD/translations/custom-toolbox_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Custom Toolbox</source>
        <translation>Niestandardowy zestaw narzędzi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Dostosuj program uruchamiający</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Zamknij program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>To jest niestandardowy program uruchamiający</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Pokaż to okno podczas uruchamiania</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>szukaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Execution Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <source>Failed to execute command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Failed to start program: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Open List File</source>
        <translation>Otwórz plik listy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>List Files (*.list)</source>
        <translation>Pliki list (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>File Selection Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>No file selected. Application will now exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>File Open Error</source>
        <translation>Błąd otwierania pliku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>The file %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Could not open file: </source>
        <translation>Nie można otworzyć&#xa0;pliku:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Custom Toolbox to narzędzie służące do tworzenia niestandardowego programu uruchamiającego</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="590"/>
        <source>%1 License</source>
        <translation>%1 Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <source>%1 Help</source>
        <translation>%1 Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Could not write file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>File Removal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>Could not remove file: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Tej aplikacji można używać do tworzenia niestandardowych programów uruchamiających: okna z przyciskami / ikonami</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Nie pokazuj pola wyboru „pokaż to okno dialogowe podczas uruchamiania”.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Pełna ścieżka i nazwa pliku .list, który chcesz załadować, aby skonfigurować aplikację</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Wygląda na to, że jesteś zalogowany jako root, wyloguj się i zaloguj jako zwykły użytkownik, aby korzystać z tego programu.</translation>
    </message>
</context>
</TS>
